@@ -2,10 +2,10 @@ from typing import (Optional, List, Dict, SupportsInt, SupportsFloat, Any,
                     Callable, TypeVar, Container, Tuple, Sequence, Type, Union)
 from bson.objectid import ObjectId
 
-from basic.dt.utils import *
-from basic.error.utils import InputDataError
-from basic.safetext import converter
-from basic.data.nametuple import is_named_tuple
+from ..dt.utils import *
+from ..error.utils import InputDataError
+from ..safetext import converter
+from ..data.nametuple import is_named_tuple
 
 
 _escape = converter.to_safe_html
